
/*******************************************************************************
 * Client.java, modified from Java: How to Program, Third Edition, Deitel
& Deitel
 * Author: Wing Ming Chan
 * Date: Apr 5, 2000
 * CPS 606, Assignment 3
 *
 * public interface:
 * 1. Client();  // constructor
 * 2. runClient();  // run the Client program by creating a socket and
 * // connect to the server
 * 3. sendData(String);  // send a message to the server
 * 4. main(String[]);


*******************************************************************************/
/*******************************************************************************
 * Protocol used by server and clients
 * 1. SHOWFILENAMES: sent by client, requesting the server to show
 * the names of available files
 * 2. FILEREQUEST: sent by client to request a file.
 * When this message is sent, the server expects a filename to follow.
 * 3. QUIT: sent by client to quit.
 * 4. Server>>>FILENOTFOUND: sent by server if file is not found.
 * 5. Server>>>FILESENDING: sent by server before the file is sent.
 * 6. Server>>>FILESENT: sent by server after the file is sent out.
 * 7. Everything else will be sent back to the client as an echo.


*******************************************************************************/
import java.io.*; import java.net.*; import java.awt.*; import
java.awt.event.*; import javax.swing.*; public class Client extends JFrame
{
  // Two global constants are placed here so that user can change
  // the values easily
  public final String serverName = "carver.npac.syr.edu";
  public final int portNumber = 7245;
  // data members
  private JTextField enter;
  private JTextArea display;
  PrintWriter output;
  BufferedReader input;
  String message = "";
  // constructor
  public Client()
  {
    // title
    super( "Client" );
    Container c = getContentPane();
    // text field for entering input
    enter = new JTextField();
    enter.setEnabled( false );
    enter.addActionListener(
      new ActionListener()
      {
        public void actionPerformed( ActionEvent e )
        {
          sendData( e.getActionCommand() );
        }
      }
    );
    c.add( enter, BorderLayout.NORTH );
    // text area for displaying information
    display = new JTextArea();
    c.add( new JScrollPane( display ), BorderLayout.CENTER );
    // set the window size
    setSize( 350, 450 );
    show();
  }
  // run the client program
  public void runClient()
  {
    Socket client;
    try
    {
      // Step 1: Create a Socket to make connection.
      display.setText( "Attempting connection\n" );
      client = new Socket(
        InetAddress.getByName( serverName ), portNumber );
      display.append( "Connected to: " +
        client.getInetAddress().getHostName() );
      // Step 2: Get the input and output streams.
      output = new PrintWriter( client.getOutputStream(), true );
      input = new BufferedReader(new InputStreamReader(
client.getInputStream() ));
      display.append( "\nGot I/O streams\n" );
      // Step 3: Process connection.
      enter.setEnabled( true );
      do
      {
        // clear the field
        enter.setText("");
        // read input and display
        message = (String) input.readLine().trim();
        display.append( "\n" + message );
        display.setCaretPosition( display.getText().length() );
        // process the messages
        if (message.equals("Server>>>FILESENDING"))
        {
          // receive the filename
          String temp = (String) input.readLine().trim();
          PrintWriter out = new PrintWriter(new FileWriter(temp), true);
          while ((temp = input.readLine()) != null && !temp.equals(
"Server>>>FILESENT" ))
          {
            out.println(temp);
          }
          out.close();
          message = temp;
          display.append( "\n" + message );
        } // end if
        if (message.equals("Server>>>FILESENT")) {}
      } while ( !message.equals( "Server>>> CLIENT QUIT" ) );
      // Step 4: Close connection.
      display.append( "\nClosing connection.\n" );
      output.close();
      input.close();
      client.close();
    }
    catch ( EOFException eof )
    {
      System.out.println( "Server terminated connection" );
    }
    catch ( IOException e )
    {
      e.printStackTrace();
    }
    // terminate program if QUIT
    if (message.equals("Server>>> CLIENT QUIT"))
    { System.exit( 0 );  }
  } // end runClient
  // send the data to server
  private void sendData( String s )
  {
    enter.setText("");
    message = s;
    output.println( s );
    display.append( "\nClient>>>" + s );
  }
  public static void main( String args[] )
   {
     Client app = new Client();
     app.addWindowListener(
       new WindowAdapter()
       {
         public void windowClosing( WindowEvent e )
         {
           System.exit( 0 );
         }
       }
     );
     app.runClient();
  } // end main 
}
